using System.Text;
using System.Threading;
using System.IO.Ports;
using GHI.Pins;
using Microsoft.SPOT;
using Microsoft.SPOT.Hardware;
using Microtoolskit.Hardware.Sensors;

namespace BrainRS232
{
    public class Program
    {
        // Slecteur de page
        private static bool pageTemperature = false;
        private static bool interruption = true;
        // --------------------------------------------------------------------------------
        // RS232 click sur le connecteur mikroBUS
        // Cration d'un objet SerialPort pour la communication avec le PC
        //public static SerialPort UART = new SerialPort("COM1", 56000, Parity.None, 8, StopBits.One);
        private static SerialPort UART = new SerialPort("COM1", 9600, Parity.None, 8, StopBits.One);
        // --------------------------------------------------------------------------------

        public static void Main()
        {
            // --------------------------------------------------------------------------------
            // Capteur de temprature TMP102 : reli au connecteur TWI de la carte d'extension
            // Communication via un adaptateur 5V <--> 3,3V BSS138
            // Cration d'un objet TMP102
            TMP102 cptTEMP102 = new TMP102();
            // --------------------------------------------------------------------------------
            // Initialisations
            cptTEMP102.Init(); UART.Open();

            // Gestion du clavier
            BrainPad.Button.ButtonPressed += Button_ButtonPressed;

            // Liste des rglages  raliser sur le PC
            AffichePageReglage();
            // --------------------------------------------------------------------------------


            while (true)
            {
                interruption = false;
                if (pageTemperature)
                {
                    // Mesure de la temprature
                    var temperature = cptTEMP102.ReadAsCelcius();

                    // Affichage 
                    BrainPad.Display.DrawExtraLargeText(20, 50, temperature.ToString("F1") + "C", BrainPad.Color.Green);
                    // Conversion de la chane en octets
                    string temperatureOnUART = "Temp. = " + temperature.ToString("f1") + "C\r"; // \r = <CR>
                    byte[] buffer = UTF8Encoding.UTF8.GetBytes(temperatureOnUART);

                    // Transmission sur le port srie
                    UART.Write(buffer, 0, buffer.Length); // Si <CR> dans la chane, <LF> ajout  la fin automatiquement !
                }
                interruption = true;
                // Attente de 1000ms 
                BrainPad.Wait.Seconds(1);
            }
        }

        private static void Button_ButtonPressed(BrainPad.Button.DPad button, BrainPad.Button.State state)
        {
            if (interruption)
            {
                if (button == BrainPad.Button.DPad.Left)
                {
                    BrainPad.Display.Clear();
                    BrainPad.Display.DrawText(10, 15, "TMP102 temperature sensor", BrainPad.Color.White);
                    for (int i = 0; i < 3; i++)
                    {
                        BrainPad.Display.DrawLine(4, 37 + i, 155, 37 + i, BrainPad.Color.Green);
                        BrainPad.Display.DrawLine(4, 87 + i, 155, 87 + i, BrainPad.Color.Green);
                    }
                    BrainPad.Display.DrawText(5, 115, "[Right] for settings", BrainPad.Color.White);
                    pageTemperature = true;
                }
                else if (button == BrainPad.Button.DPad.Right)
                {
                    pageTemperature = false;
                    AffichePageReglage();
                }
            }
        }

        private static void AffichePageReglage()
        {
            // Message
            BrainPad.Display.Clear();
            BrainPad.Display.DrawLargeText(10, 15, "TP SI RS232", BrainPad.Color.Yellow);
            BrainPad.Display.DrawLine(4, 37, 155, 37, BrainPad.Color.Green);
            BrainPad.Display.DrawText(5, 45, "Set this parameters on PC", BrainPad.Color.Red);
            BrainPad.Display.DrawText(5, 60, "Port      : " + UART.PortName, BrainPad.Color.Yellow);
            BrainPad.Display.DrawText(5, 70, "Baud rate : " + UART.BaudRate, BrainPad.Color.Yellow);
            BrainPad.Display.DrawText(5, 80, "Data bits : " + UART.DataBits, BrainPad.Color.Yellow);
            BrainPad.Display.DrawText(5, 90, "Stop bits : " + UART.StopBits, BrainPad.Color.Yellow);
            BrainPad.Display.DrawText(5, 100, "Parity    : " + UART.Parity, BrainPad.Color.Yellow);
            BrainPad.Display.DrawText(5, 115, "Push [Left] button", BrainPad.Color.White);
        }
    }
}
